/*
 * @Description:
 * @Version: 2.0
 * @Autor: ruog__
 * @Date: 2022-08-08 13:32:24
 * @LastEditors: ruog__
 * @LastEditTime: 2022-09-06 17:03:35
 */
#ifndef __DID__
#define __DID__
#include <stdio.h>
#include <stdlib.h>

#ifndef __OUTPUT__
#define __OUTPUT__ //出参标记
#define __INPUT__  //入参标记
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define DID_LEN 94
#define DEFAULT_LEN 1024

#pragma pack(1)
typedef struct _didInfo
{
    /* data */
    unsigned char did[DID_LEN + 1]; // 94字节  did长度
    unsigned char reserved[DEFAULT_LEN - DID_LEN -1];      //预留
} didInfo;
#pragma pack()

/*
function:校验DID完整性
  input: p_did --- did缓存
    length --- p_did长度
  output: N/A
    ischeckPass: 校验是否通过，1.通过，0.不通过
    return: -1 --- 校验DID失败
    0 --- 校验DID成功
*/
int uoshwinfo_did_checksum(didInfo __INPUT__ *p_did_info, int *ischeckPass);

/*
function:解析DID版本号
input: 
    p_did --- did缓存
    length --- p_dsid长度
    ver --- DID版本号
output: 
    ver --- DID版本号
    return: -1 --- 解析DID版本号失败
    0 --- 解析DID版本号成功
*/
int uoshwinfo_did_parse_ver(didInfo __INPUT__ *p_did, unsigned char __OUTPUT__ *ver);

/*
function:获取当前操作系统DID
    input: 
        did --- did缓存
        ver --- did版本号
    output: 
        did --- did结果
    return: 
        -1 --- 获取did失败
        0 --- 获取did成功
*/
int uoshwinfo_did_get_id(didInfo __OUTPUT__ *did, unsigned char __INPUT__ ver);


/**
 * @brief 判断当前环境是否为docker，是docker时才能进行以下接口.
 * 
 * @return int isDocker= 1，  为docker
 */
int uoshwinfo_did_detect_docker(int *isDocker);

/**
 * @brief 获取当前系统的容器id
 * 
 * @param c_id 
 * @param c_id_len 
 * @return int 
 */
int uoshwinfo_did_get_containerId(unsigned char *c_id, int c_id_len);


/**
 * @brief 获取此docker的权限,判断是否有主机权限
 * 
 * @return int isPass权限是否校验通过
 */
int uoshwinfo_did_get_permisson_for_dockerid(int *isPass);


/**
 * @brief docker 宿主机是否为虚拟机
 * 
 * @param isVM 
 * @return int 
 */
int uoshwinfo_detect_vm(int *isVM);


/*
function:获取当前LXD容器id
    input: 
        did          --- lxd容器id缓存
        pinstance_id --- lxd容器instance-id
    output: 
        did --- lxd容器id结果
    return: 
        -1 --- 获取lxd容器id失败
         0 --- 获取lxd容器id成功
*/
int uoshwinfo_get_lxd_id(didInfo *did, unsigned char *pinstance_id);

#ifdef __cplusplus
}
#endif
#endif
