#ifndef __HWINFO_H__
#define __HWINFO_H__

#ifdef __cplusplus
extern "C" {
#endif

#define SIG_HWINFO_LEN 128

/*硬盘信息*/
typedef struct uoshwinfo_deviceh_hwdisk 
{
  char product[SIG_HWINFO_LEN];
  char serial[SIG_HWINFO_LEN];
  char version[SIG_HWINFO_LEN];
  char name[SIG_HWINFO_LEN];
  unsigned long long size;
  unsigned char is_root;
  unsigned char is_removable;
  unsigned char is_virtual;
 
}uoshwinfo_deviceh_hwdisk;


/*BIOS信息*/
typedef struct uoshwinfo_deviceh_bios 
{
  char vendor[SIG_HWINFO_LEN];
  char version[SIG_HWINFO_LEN];
  char date[SIG_HWINFO_LEN];
  char oeminfo[SIG_HWINFO_LEN];

}uoshwinfo_deviceh_bios;


/*SYSTEM信息*/
typedef struct uoshwinfo_deviceh_system 
{
  char product[SIG_HWINFO_LEN];
  char vendor[SIG_HWINFO_LEN];
  char serial[SIG_HWINFO_LEN];
  char version[SIG_HWINFO_LEN];
  char uuid[SIG_HWINFO_LEN];

}uoshwinfo_deviceh_system;

/*主板信息*/
typedef struct uoshwinfo_deviceh_board 
{
  char product[SIG_HWINFO_LEN];
  char vendor[SIG_HWINFO_LEN];
  char serial[SIG_HWINFO_LEN];
  char version[SIG_HWINFO_LEN];

}uoshwinfo_deviceh_board;

/*CPU信息*/
typedef struct uoshwinfo_deviceh_cpu 
{
  char product[SIG_HWINFO_LEN];
  char vendor[SIG_HWINFO_LEN];
  char serial[SIG_HWINFO_LEN];
  char version[SIG_HWINFO_LEN];
  char arch[SIG_HWINFO_LEN];

}uoshwinfo_deviceh_cpu;

/*内存信息*/ 
typedef struct uoshwinfo_deviceh_mem
{
  char product[SIG_HWINFO_LEN];
  char vendor[SIG_HWINFO_LEN];
  char serial[SIG_HWINFO_LEN];
  unsigned long long speed;
  unsigned long long size;

}uoshwinfo_deviceh_mem;

/*网卡信息*/
typedef struct uoshwinfo_deviceh_net 
{
  char version[SIG_HWINFO_LEN];
  char mac[SIG_HWINFO_LEN]; 
  char name[SIG_HWINFO_LEN];
  unsigned char is_virtual; //0:物理网卡, 1:虚拟网卡, 0xff:获取失败
  unsigned char index;    //0:获取失败, other:网卡索引
  unsigned char is_enabled;   //1:网卡开启, 0:网卡关闭, 0xff:获取失败
  unsigned char is_removable; //0：非移动网卡， 1:移动网卡
}uoshwinfo_deviceh_net;

/*RAID信息*/
typedef struct uoshwinfo_deviceh_hwraid
{
  unsigned char hwraid_exist;  //硬raid是否存在
  unsigned char hwraid_status; //硬raid是否启用
  unsigned char vroc_exist;    //vroc是否存在
  unsigned char vroc_status;   //vroc是否启用
  unsigned char sraid_exist;   //软raid是否存在
  unsigned char sraid_status;  //软raid是否启用
} uoshwinfo_deviceh_hwraid;

/*虚拟机类型信息*/
typedef struct uoshwinfo_deviceh_vm 
{
  char vm_type[SIG_HWINFO_LEN]; //未知:unknown, 报错: error, 物理机:none, 虚拟机:vmware，qemu，virtual box ...
  unsigned char env_type; //0:未知, 1:物理机环境, 2:虚拟机环境, 3:容器环境, 0xFF:报错
}uoshwinfo_deviceh_vm;

/*版本信息*/
typedef struct uoshwinfo_deviceh_version 
{
  char version[SIG_HWINFO_LEN];

}uoshwinfo_deviceh_version;



/**
 * 根分区uuid和根分区起始扇区
 */
typedef struct uoshwinfo_deviceh_partinfo
{
  char uuid[SIG_HWINFO_LEN*4];
  char start_sec[SIG_HWINFO_LEN];
}uoshwinfo_deviceh_partinfo;


///////////////////////////////////////////////////////////////////////////////////

/*function:获取当前设备硬盘数量
  input:N/A 
  output:pdisknum--硬盘数量
  return: -1 -- 获取硬盘数量失败
           0 -- 获取硬盘数量成功
*/
int uoshwinfo_deviceh_get_disk_num(int *pdisknum);

/*function:获取当前设备硬盘信息
  input:N/A
  output:pdiskinfo--硬盘信息数据结构；如果获取失败则数据内容为空
  return: -1 -- 获取硬盘信息失败
           0 -- 获取硬盘信息成功
*/
int uoshwinfo_deviceh_get_disk(uoshwinfo_deviceh_hwdisk *pdiskinfo, int *pcount);


/*function:获取当前设备BIOS信息
  input:N/A
  output:pbiosinfo--BIOS信息数据结构；如果获取失败则数据内容为空
  return: -1 -- 获取bios信息失败
           0 -- 获取bios信息成功
*/
int uoshwinfo_deviceh_get_bios(uoshwinfo_deviceh_bios *pbiosinfo);


/*function:获取当前设备主板信息
  input:N/A
  output:pboardinfo--主板信息数据结构；如果获取失败则数据内容为空
  return: -1 -- 获取主板信息失败
           0 -- 获取主板信息成功
*/
int uoshwinfo_deviceh_get_board(uoshwinfo_deviceh_board *pboardinfo);


/*function:获取当前设备主机信息
  input:N/A
  output:psysteminfo--主机信息数据结构；如果获取失败则数据内容为空
  return: -1 -- 获取主机信息失败
           0 -- 获取主机信息成功
*/
int uoshwinfo_deviceh_get_system(uoshwinfo_deviceh_system *psysteminfo);


/*function:获取当前设备CPU数量
  input:N/A                   
  output:pcount--CPU数量
  return: -1 -- 获取CPU数量失败
           0 -- 获取CPU数量成功
*/
int uoshwinfo_deviceh_get_cpu_num(int *pcount);

/*function:获取当前设备CPU信息
  input:N/A
  output:pcpuinfo--CPU信息数据结构；如果获取失败则数据内容为空
         pcount--pcpuinfo结构数组大小地址
  return: -1 -- 获取CPU信息失败
           0 -- 获取CPU信息成功
*/
int uoshwinfo_deviceh_get_cpu(uoshwinfo_deviceh_cpu *pcpuinfo, int *pcount);


/*function:获取当前设备内存数量
  input:N/A
  output:pcount--内存数量
  return: -1 -- 获取内存数量失败
           0 -- 获取内存数量成功
*/
int uoshwinfo_deviceh_get_memory_num(int *pcount);

/*function:获取当前设备内存信息
  input:N/A
  output:pmeminfo--内存信息数据结构；如果获取失败则数据内容为空
         pcount--pmeminfo结构数组大小地址
  return: -1 -- 获取内存信息失败
           0 -- 获取内存信息成功
*/
int uoshwinfo_deviceh_get_memory(uoshwinfo_deviceh_mem *pmeminfo, int *pcount);


/*function:获取当前设备net数量
  input:N/A                   
  output:pcount--net数量
  return: -1 -- 获取net数量失败
           0 -- 获取net数量成功
*/
int uoshwinfo_deviceh_get_net_num(int *pcount);

/*function:获取当前设备网卡信息
  input:N/A
  output:pnetinfo--网卡信息数据结构；如果获取失败则数据内容为空
         pcount--pnetinfo结构数组大小地址
  return: -1 -- 获取网卡信息失败
           0 -- 获取网卡信息成功
*/
int uoshwinfo_deviceh_get_net(uoshwinfo_deviceh_net *pnetinfo, int *pcount);


/*function:获取当前设备虚拟机信息
  input:N/A
  output:pvminfo--虚拟机信息数据结构；
                  成员变量type说明：
				  error: 获取虚拟机信息失败
				  none:  不是虚拟机
				  qemu,kvm....: 具体虚拟机类型
  return: -1 -- 获取当前设备虚拟机信息失败
           0 -- 获取当前设备虚拟机信息成功
*/
int uoshwinfo_deviceh_get_vm(uoshwinfo_deviceh_vm *pvminfo);


/*function:获取当前设备RADI信息
  input:N/A
  output:phwraidinfo--RAID信息数据结构；
                      成员变量说明：

  return:-1 -- 获取失败
         0 -- 获取成功
 */
int uoshwinfo_deviceh_get_raid(uoshwinfo_deviceh_hwraid *phwraidinfo);


/*function:获取当前libuosdeviceh.so库版本号
  input:N/A
  output:pversioninfo--版本号信息数据结构
  return: -1 -- 获取libuosdeviceh.so库版本号失败
           0 -- 获取libuosdeviceh.so库版本号成功
 */
int uoshwinfo_deviceh_get_version(uoshwinfo_deviceh_version *pversioninfo);


/*function: 获取UTDM文件的内容
  input:putdm_path--UTDM表路径
  output:putdm_buff--UTDM表内容，传入的内存指针,内存空间由库申请，调用者释放
         putdm_bufflen--UTDM表大小，也就是库内申请的内存大小
  return:-1 -- 获取失败
         0 -- 获取成功
 */
int uoshwinfo_deviceh_get_uosdm(char **putdm_buff, long *putdm_bufflen, char *putdm_path);




/*function: 获取根分区UUID
  output:uoshwinfo_deviceh_partinfo --用来保存uuid的buf首地址

  return:-1 -- 获取失败
         0 -- 获取成功
 */
int uoshwinfo_deviceh_get_rootinfo(uoshwinfo_deviceh_partinfo *uuid_buff);



/*function: 释放硬件信息缓存 
  return:N/A
 */
void uoshwinfo_util_cache_free();

#ifdef __cplusplus
}
#endif
#endif //__HWINFO_H__
